@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -19,9 +19,7 @@ KDEApplicationTreeListWidgetItem::KDEApplicationTreeListWidgetItem(const QString
     treeWidget()->setItemWidget(this, CategoryType, mCategoryTypeCombobox);
 }
 
-KDEApplicationTreeListWidgetItem::~KDEApplicationTreeListWidgetItem()
-{
-}
+KDEApplicationTreeListWidgetItem::~KDEApplicationTreeListWidgetItem() = default;
 
 void KDEApplicationTreeListWidgetItem::restoreToDefault()
 {
@@ -69,9 +67,7 @@ KDEApplicationTreeListWidget::KDEApplicationTreeListWidget(QWidget *parent)
     header()->hide();
 }
 
-KDEApplicationTreeListWidget::~KDEApplicationTreeListWidget()
-{
-}
+KDEApplicationTreeListWidget::~KDEApplicationTreeListWidget() = default;
 
 QList<int> KDEApplicationTreeListWidget::searchColumns() const
 {
