@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,9 +12,7 @@
 #include <QVector>
 struct LIBKDEBUGSETTINGS_EXPORT_TEST_EXPORT RenameCategory {
 public:
-    RenameCategory()
-    {
-    }
+    RenameCategory() = default;
 
     using List = QVector<RenameCategory>;
     Q_REQUIRED_RESULT bool operator==(const RenameCategory &other) const;
